==> tclTCP2.0.tar.gz: simple.c <==
#include <stdio.h>
/*
 * Dummy main program for testing the tclTCP package.
 */

char RCSid_simple [] =
  "$Header: /a/src3/tcl7.1/tclTCP1.1/RCS/simple.c,v 1.1 1992/10/28 18:51:36 vanandel Exp vanandel $";
/* $Source: /a/src3/tcl7.1/tclTCP1.1/RCS/simple.c,v $
 * $Log: simple.c,v $
 * Revision 1.1  1992/10/28  18:51:36  vanandel
 * Initial revision
 *
 * Revision 1.2  1992/02/25  15:20:56  kennykb
 * Modifications to quiet gcc's warnings.
 *
 * Revision 1.1  1992/02/14  19:57:51  kennykb
 * Initial revision
 *
 */
/* drag in main from tcl library */
extern int main();
int *tclDummyMainPtr = (int *) main;


char copyright_simple [] = 
  "Copyright (C) 1992 General Electric. All rights reserved."		;

/*
 *   Permission to use, copy, modify, and distribute this
 *   software and its documentation for any purpose and without
 *   fee is hereby granted, provided that the above copyright
 *   notice appear in all copies and that both that copyright
 *   notice and this permission notice appear in supporting
 *   documentation, and that the name of General Electric not be used in
 *   advertising or publicity pertaining to distribution of the
 *   software without specific, written prior permission.
 *   General Electric makes no representations about the suitability of
 *   this software for any purpose.  It is provided "as is"
 *   without express or implied warranty.
 *
 *   This work was supported by the DARPA Initiative in Concurrent
 *   Engineering (DICE) through DARPA Contract MDA972-88-C-0047.
 */

static char MyScript[] =  "\
source [info library]/init.tcl\n\
proc bye {} {\n\
        foreach s [tcp servers] {\n\
                $s stop\n\
        }\n\
}\n\
set s [tcp server -port 2323 -command \"tcp eval\"]\n\
puts stderr \"server is $s\"\n\
$s start\n\
puts stderr \"$s started\"\n\
set status [tcp mainloop]\n\
puts stderr \"tcp mainloop returns $status\"\n\
";

#include <tcl.h>
Tcl_AppInit(interp)
    Tcl_Interp *interp;         /* Interpreter for application. */

{
    int status;
    if (Tcl_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

    TclTCP_Init(interp); 

    status = Tcl_Eval(interp, MyScript);




  if (status != TCL_OK) {
    fprintf (stderr, "%s\n\n", interp -> result);
  }

}

==> tclTCP2.1.tar.gz: simple.c <==
#include <stdio.h>
/*
 * Dummy main program for testing the tclTCP package.
 */

char RCSid_simple [] =
  "$Header: /net/src3/btcl/tclTCP2.1/RCS/simple.c,v 1.2 1994/07/12 23:38:43 vanandel Exp $";
/* $Source: /net/src3/btcl/tclTCP2.1/RCS/simple.c,v $
 * $Log: simple.c,v $
 * Revision 1.2  1994/07/12  23:38:43  vanandel
 * cleanup/port
 *
 * Revision 1.1  1992/10/28  18:51:36  vanandel
 * Initial revision
 *
 * Revision 1.2  1992/02/25  15:20:56  kennykb
 * Modifications to quiet gcc's warnings.
 *
 * Revision 1.1  1992/02/14  19:57:51  kennykb
 * Initial revision
 *
 */
/* drag in main from tcl library */
extern int main();
int *tclDummyMainPtr = (int *) main;


char copyright_simple [] = 
  "Copyright (C) 1992 General Electric. All rights reserved."		;

/*
 *   Permission to use, copy, modify, and distribute this
 *   software and its documentation for any purpose and without
 *   fee is hereby granted, provided that the above copyright
 *   notice appear in all copies and that both that copyright
 *   notice and this permission notice appear in supporting
 *   documentation, and that the name of General Electric not be used in
 *   advertising or publicity pertaining to distribution of the
 *   software without specific, written prior permission.
 *   General Electric makes no representations about the suitability of
 *   this software for any purpose.  It is provided "as is"
 *   without express or implied warranty.
 *
 *   This work was supported by the DARPA Initiative in Concurrent
 *   Engineering (DICE) through DARPA Contract MDA972-88-C-0047.
 */

static char MyScript[] =  "\
source [info library]/init.tcl\n\
proc bye {} {\n\
        foreach s [tcp servers] {\n\
                $s stop\n\
        }\n\
}\n\
set s [tcp server -port 2323 -command \"tcp eval\"]\n\
puts stderr \"server is $s\"\n\
$s start\n\
puts stderr \"$s started\"\n\
set status [tcp mainloop]\n\
puts stderr \"tcp mainloop returns $status\"\n\
";

#include <tcl.h>
Tcl_AppInit(interp)
    Tcl_Interp *interp;         /* Interpreter for application. */

{
    int status;
    if (Tcl_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

    TclTCP_Init(interp); 

    status = Tcl_Eval(interp, MyScript);




  if (status != TCL_OK) {
    fprintf (stderr, "%s\n\n", interp -> result);
  }

}
